==> dl.php?src=linea21_2_5_0.zip: linea21/dashboard/sup.php <==
<?php
/**
 * Dashboard module
 * 
 * Delete indicator given value from back-office
 * 
 * @package linea21\modules\dashboard
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////


if (!isset($_GET['value_id']) && !isset($_POST['value_id'])) {
	$value_id = 1;
} else {
	if (isset($_POST['value_id'])) $value_id = $_POST['value_id'];
	if (isset($_GET['value_id'])) $value_id = $_GET['value_id'];
}
if (!isset($_GET['id']) && !isset($_POST['id'])) {
	$id = 1;
} else {
	if (isset($_POST['id'])) $id = $_POST['id'];
	if (isset($_GET['id'])) $id = $_GET['id'];
}
if (!isset($_GET['scale_id']) && !isset($_POST['scale_id'])) {
	$scale_id = 1;
} else {
	if (isset($_POST['scale_id'])) $scale_id = $_POST['scale_id'];
	if (isset($_GET['id'])) $scale_id = $_GET['scale_id'];
}

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('dashboard')  && !$l21auth->hasRight('indicator', $id)) ReloadIndex('admin');
////////////


$link_det=$rub_link."&amp;todo=det&amp;id=";
$link_det2=$rub_link."&todo=det&id=";

if(isset($_POST['valider'])) {
  $value_id=$_POST['value_id'];
  $sdi_object= new sdi;
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo."&id=".$id."&scale_id=".$scale_id;

  $result=$sdi_object->DeleteValue($value_id, $sql_object);
  if($result) {
      header("Location: ".safe_redirect($link_confirm));
      exit;
  }
  else  system_error();
}

$req_sdii=SQL_getInfoSdi($id);
$data_sdii = $sql_object -> DBSelect($req_sdii);

// Do record exists?
if(!isset($data_sdii[0]['sdii_name'])) redirect_to('@module_default');

$display_title = formatText($data_sdii[0]['sdii_name'], '2HTML');

?>
<div id="chemin">
  <ul>
  	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home');  ?></a></li>
  	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','dashboard'); ?></a></li>
  	<li><span><?php echo formatnavTitle(_t('dashboard','sup').' : '.$display_title); ?></span></li>
  </ul>
</div>
<!--end barre haute -->

<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content">
<?php
if(isset($integrity) && is_string($integrity)) display_errors($integrity);
?>

<h2><?php echo formatTitleh2(mb_ucfirst(_t('dashboard','sup'))); ?></h2>
<div id="dashboard-subtitle" class="subtitle"><i class="icon-chart-bar"></i><?php echo $display_title; ?></div>

<form id="supvalue" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
    <div class="info" id="truetransfert1">
      <i class="icon-trash"></i> <?php echo _t('dashboard','sup_value_warning'); ?>
    </div>
    <div>
      <input name="id" type="hidden" value="<?php echo $id; ?>" />
      <input name="scale_id" type="hidden" value="<?php echo $scale_id; ?>" />
      <input name="value_id" type="hidden" value="<?php echo $value_id; ?>" />
      <input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
      <input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
      <?php echo cancel_button($link_det2.$id); ?>
      <input name="valider" type="submit" value="<?php echo _t('btn','valid') ?>" class="button" id="valider" />
    </div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->

==> dl.php?src=linea21_2_8_0.zip: linea21/dashboard/sup.php <==
<?php
/**
 * Dashboard module
 * 
 * Delete indicator given value from back-office
 * 
 * @package linea21\modules\dashboard
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')){
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////


if (!isset($_GET['value_id']) && !isset($_POST['value_id'])) {
	$value_id = 1;
} else {
	if (isset($_POST['value_id'])) $value_id = $_POST['value_id'];
	if (isset($_GET['value_id'])) $value_id = $_GET['value_id'];
}
if (!isset($_GET['id']) && !isset($_POST['id'])) {
	$id = 1;
} else {
	if (isset($_POST['id'])) $id = $_POST['id'];
	if (isset($_GET['id'])) $id = $_GET['id'];
}
if (!isset($_GET['scale_id']) && !isset($_POST['scale_id'])) {
	$scale_id = 1;
} else {
	if (isset($_POST['scale_id'])) $scale_id = $_POST['scale_id'];
	if (isset($_GET['id'])) $scale_id = $_GET['scale_id'];
}

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('dashboard')  && !$l21auth->hasRight('indicator', $id)) ReloadIndex('admin');
////////////


$link_det=$rub_link."&amp;todo=det&amp;id=";
$link_det2=$rub_link."&todo=det&id=";

if(isset($_POST['valider'])) {
  $value_id=$_POST['value_id'];
  $sdi_object= new sdi;
  $link_confirm="confirm.php?rub=".$rub."&todo=".$todo."&id=".$id."&scale_id=".$scale_id;

  $result=$sdi_object->DeleteValue($value_id, $sql_object);
  if($result) {
      header("Location: ".safe_redirect($link_confirm));
      exit;
  }
  else  system_error();
}

$req_sdii=SQL_getInfoSdi($id);
$data_sdii = $sql_object -> DBSelect($req_sdii);

// Do record exists?
if(!isset($data_sdii[0]['sdii_name'])) redirect_to('@module_default');

$display_title = formatText($data_sdii[0]['sdii_name'], '2HTML');

?>
<div id="chemin">
  <ul>
  	<li><a href="index.php" class="chemin_home"><?php echo _t('way','home');  ?></a></li>
  	<li><a href="<?php echo $rub_link; ?>" id="chemin_<?php echo $rub; ?>" class="chemin_rub"><?php echo _t('menu','dashboard'); ?></a></li>
  	<li><span><?php echo formatnavTitle(_t('dashboard','sup').' : '.$display_title); ?></span></li>
  </ul>
</div>
<!--end barre haute -->

<div class="contentcontainer"><?php
include_once(override($dir.'/menurub.php', THEME_ADMIN_PATH));
?>
<div id="content">
<?php
if(isset($integrity) && is_string($integrity)) display_errors($integrity);
?>

<h2><?php echo formatTitleh2(mb_ucfirst(_t('dashboard','sup'))); ?></h2>
<div id="dashboard-subtitle" class="subtitle"><i class="fa fa-bar-chart" aria-hidden="true"></i><?php echo $display_title; ?></div>

<form id="supvalue" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
    <div class="info" id="truetransfert1">
      <i class="fa fa-trash"></i> <?php echo _t('dashboard','sup_value_warning'); ?>
    </div>
    <div>
      <input name="id" type="hidden" value="<?php echo $id; ?>" />
      <input name="scale_id" type="hidden" value="<?php echo $scale_id; ?>" />
      <input name="value_id" type="hidden" value="<?php echo $value_id; ?>" />
      <input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
      <input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
      <?php echo cancel_button($link_det2.$id); ?>
      <input name="valider" type="submit" value="<?php echo _t('btn','valid') ?>" class="button" id="valider" />
    </div>
</form>
</div> <!-- closing #content -->
</div> <!-- closing .contentcontainer -->
